lilypondnametools.LilyPondGrobNameManager
=========================================

.. abjad-lineage:: abjad.tools.lilypondnametools.LilyPondGrobNameManager.LilyPondGrobNameManager

.. autoclass:: abjad.tools.lilypondnametools.LilyPondGrobNameManager.LilyPondGrobNameManager

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondnametools.LilyPondGrobNameManager.LilyPondGrobNameManager.__eq__
      ~abjad.tools.lilypondnametools.LilyPondGrobNameManager.LilyPondGrobNameManager.__format__
      ~abjad.tools.lilypondnametools.LilyPondGrobNameManager.LilyPondGrobNameManager.__getattr__
      ~abjad.tools.lilypondnametools.LilyPondGrobNameManager.LilyPondGrobNameManager.__hash__
      ~abjad.tools.lilypondnametools.LilyPondGrobNameManager.LilyPondGrobNameManager.__ne__
      ~abjad.tools.lilypondnametools.LilyPondGrobNameManager.LilyPondGrobNameManager.__repr__
      ~abjad.tools.lilypondnametools.LilyPondGrobNameManager.LilyPondGrobNameManager.__setattr__

Bases
-----

- :py:class:`lilypondnametools.LilyPondNameManager <abjad.tools.lilypondnametools.LilyPondNameManager.LilyPondNameManager>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.lilypondnametools.LilyPondGrobNameManager.LilyPondGrobNameManager.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondnametools.LilyPondGrobNameManager.LilyPondGrobNameManager.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondnametools.LilyPondGrobNameManager.LilyPondGrobNameManager.__getattr__
   :noindex:

.. automethod:: abjad.tools.lilypondnametools.LilyPondGrobNameManager.LilyPondGrobNameManager.__hash__
   :noindex:

.. automethod:: abjad.tools.lilypondnametools.LilyPondGrobNameManager.LilyPondGrobNameManager.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondnametools.LilyPondGrobNameManager.LilyPondGrobNameManager.__repr__
   :noindex:

.. automethod:: abjad.tools.lilypondnametools.LilyPondGrobNameManager.LilyPondGrobNameManager.__setattr__
   :noindex:
